# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litepci/grade/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/litepci/grade/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Litepci\\Grade\\": "packages/litepci/grade/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litepci\Grade\Providers\GradeServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Grade'  => Litepci\Grade\Facades\Grade::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litepci\\GradeTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litepci\Grade\Providers\GradeServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litepci\Grade\Providers\GradeServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litepci\Grade\Providers\GradeServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/grade/{modulename}

**User**

    http://path-to-route-folder/user/grade/{modulename}

**Public**

    http://path-to-route-folder/grades


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/grade/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/grade/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/grade/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/grade/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/grade/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/grade/{modulename}/{slug}
    METHOD: GET